#
# spec file for package libqt5-qtdatavis3d
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define qt5_snapshot 0

%define libname libQt5DataVisualization5

Name:           libqt5-qtdatavis3d
Version:        5.12.7
Release:        lp152.1.3
Summary:        Qt5 Data Visualization 3D
License:        GPL-3.0
Group:          Development/Libraries/X11
Url:            http://doc.qt.io/qt-5/qtdatavisualization-index.html
%define base_name libqt5
%define real_version 5.12.7
%define so_version 5.12.7
%define tar_version qtdatavis3d-everywhere-src-5.12.7
Source:         https://download.qt.io/official_releases/qt/5.12/%{real_version}/submodules/%{tar_version}.tar.xz
BuildRequires:  libqt5-qtdeclarative-devel >= %{version}
BuildRequires:  fdupes

%if %qt5_snapshot
#to create the forwarding headers
BuildRequires:  perl
%endif
BuildRequires:  xz
%requires_ge libQtQuick5

%description
Qt5 Data Visualization module provides a way to visualize data in 3D.

  * Multiple data visualization options: 3D Bars, 3D Scatter, and 3D Surface
  * 2D slice views of the 3D data
  * Interactive data: rotate, zoom, and highlight data using mouse or touch
  * Uses OpenGL for rendering the data
  * QML2 support
  * Customizable axes for data
      - Control viewable data window with axis ranges
      - Customize value axis grid lines and labels with axis formatters
      - Polar horizontal axes support for surface and scatter graphs
  * Customizable input handling
  * Customizable themes
  * Custom items and labels can be added to any graph
  * Ready-made data proxies to visualize data from Qt item models and height maps
  * Perspective and orthographic projections
  * Volumetric custom items

%prep
%setup -q -n qtdatavis3d-everywhere-src-%{real_version}

%package -n %libname
Summary:        Qt5 Data Visualization module
Group:          System/Libraries
%requires_ge libQt5Core5

%description -n %libname
Qt Data Visualization module provides a way to visualize data in 3D.

This package contains a shared library for the QtDataVisualization.

%package -n %{libname}-devel
Summary:        Development files for the Qt5 Data Visualization module
Group:          Development/Libraries/X11
Requires:       %{libname} = %{version}

%description -n %{libname}-devel
This package provides header files and shared libraries for development with
Qt Data Visualization.

%package examples
Summary:        Examples for the Qt5 Data Visualization module
Group:          Development/Libraries/X11
Recommends:     %{libname}-devel

%description examples
This package provides examples for Qt 5 Data Visualization module.

%package imports
Summary:        QML imports for the Qt5 Data Visualization module
Group:          Development/Libraries/X11
Supplements:    packageand(%{libname}:libDataVisualization5)
%requires_ge libDataVisualization5

%description imports
This package contains QML import files for Qt5 Data Visualization module.

%post -n %libname -p /sbin/ldconfig

%postun -n %libname -p /sbin/ldconfig

%build
%if %qt5_snapshot
#force the configure script to generate the forwarding headers (it checks whether .git directory exists)
mkdir .git
%endif
%qmake5
%make_jobs

%install
%qmake5_install
%fdupes %{buildroot}/%{_libqt5_examplesdir}

# kill .la files
rm -f %{buildroot}%{_libqt5_libdir}/lib*.la

%files -n %libname
%license LICENSE.*
%{_libqt5_libdir}/libQt5DataVisualization.so.*

%files -n %{libname}-devel
%{_libqt5_libdir}/libQt5DataVisualization.so
%{_libqt5_libdir}/libQt5DataVisualization.prl
%{_libqt5_libdir}/cmake/Qt5DataVisualization/
%{_libqt5_libdir}/pkgconfig/Qt5DataVisualization.pc
%{_libqt5_archdatadir}/mkspecs/modules/qt_lib_datavisualization.pri
%{_libqt5_archdatadir}/mkspecs/modules/qt_lib_datavisualization_private.pri
%{_libqt5_includedir}/QtDataVisualization/
%exclude %{_libqt5_includedir}/Qt*/%{so_version}/

%files examples
%license examples/datavisualization/texturesurface/license.txt
%{_libqt5_examplesdir}/

%files imports
%{_libqt5_archdatadir}/qml/*/

%changelog
* Fri Jan 31 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.12.7:
  * New bugfix release
  * For more details please see:
    http://code.qt.io/cgit/qt/qtdatavis3d.git/plain/dist/changes-5.12.7/?h=v5.12.7
* Thu Nov 14 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.12.6:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtdatavis3d.git/plain/dist/changes-5.12.6/?h=v5.12.6
* Thu Sep 12 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.12.5:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtdatavis3d.git/plain/dist/changes-5.12.5/?h=5.12.5
* Fri Jun 14 2019 fabian@ritter-vogt.de
- Update to 5.12.4:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtdatavis3d.git/plain/dist/changes-5.12.4/?h=5.12.4
* Thu Apr 18 2019 fabian@ritter-vogt.de
- Update to 5.12.3:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtdatavis3d.git/plain/dist/changes-5.12.3/?h=v5.12.3
* Thu Mar 14 2019 fabian@ritter-vogt.de
- Update to 5.12.2:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtdatavis3d.git/plain/dist/changes-5.12.2/?h=5.12.2
* Fri Feb  1 2019 fabian@ritter-vogt.de
- Update to 5.12.1:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtdatavis3d.git/plain/dist/changes-5.12.1/?h=v5.12.1
* Wed Dec 19 2018 Fabian Vogt <fabian@ritter-vogt.de>
- Use %%license
- Remove empty libqt5-qtdatavis3d package
* Thu Dec  6 2018 fabian@ritter-vogt.de
- Update to 5.12.0:
  * New feature release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtdatavis3d.git/plain/dist/changes-5.12.0/?h=v5.12.0
* Mon Dec  3 2018 fabian@ritter-vogt.de
- Update to 5.12.0-rc2:
  * New bugfix release
  * Only important bugfixes
- Changelog for Qt 5.12.0:
  * http://code.qt.io/cgit/qt/qtdatavis3d.git/plain/dist/changes-5.12.0/?h=5.12.0
* Thu Nov 22 2018 fabian@ritter-vogt.de
- Update to 5.12.0-rc:
  * New bugfix release
  * No changelog available
* Thu Nov  8 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta4:
  * New bugfix release
  * No changelog available
* Fri Oct 26 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta3:
  * New bugfix release
  * No changelog available
* Wed Oct 17 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta2:
  * New bugfix release
  * No changelog available
* Fri Oct  5 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta1:
  * New bugfix release
  * No changelog available
* Tue Oct  2 2018 fabian@ritter-vogt.de
- Update to 5.12.0-alpha:
  * New feature release
  * For more details please see:
  * http://wiki.qt.io/New_Features_in_Qt_5.12
* Fri Sep 21 2018 fabian@ritter-vogt.de
- Update to 5.11.2
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtdatavis3d.git/plain/dist/changes-5.11.2/?h=v5.11.2
* Tue Jun 19 2018 fabian@ritter-vogt.de
- Update to 5.11.1
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtdatavis3d.git/plain/dist/changes-5.11.1/?h=v5.11.1
* Tue May 22 2018 fabian@ritter-vogt.de
- Update to 5.11.0
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtdatavis3d.git/plain/dist/changes-5.11.0/?h=v5.11.0
* Tue May  8 2018 fabian@ritter-vogt.de
- Update to 5.11.0-rc
  * New bugfix release
  * No changelog available
* Mon Apr 23 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta4
  * New bugfix release
  * No changelog available
* Wed Apr 11 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta3
  * New bugfix release
  * No changelog available
* Wed Mar 28 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta2
  * New bugfix release
  * No changelog available
* Thu Mar  1 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta1
  * New feature release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtdatavis3d.git/plain/dist/changes-5.11.0-beta1/?h=v5.11.0-beta1
* Tue Feb 20 2018 fabian@ritter-vogt.de
- Update to 5.11.0-alpha
  * New feature release
  * For more details please see:
  * https://wiki.qt.io/New_Features_in_Qt_5.11
* Wed Feb 14 2018 fabian@ritter-vogt.de
- Update to 5.10.1
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtdatavis3d.git/plain/dist/changes-5.10.1/?h=v5.10.1
* Thu Dec  7 2017 fabian@ritter-vogt.de
- Update to 5.10.0 final
  * New bugfix release
* Sun Dec  3 2017 fabian@ritter-vogt.de
- Update to 5.10.0 RC 2
  * New bugfix release
* Thu Nov 30 2017 fabian@ritter-vogt.de
- Update to 5.10.0 RC 1
  * New bugfix release
* Sat Nov 25 2017 fabian@ritter-vogt.de
- Update to 5.9.3
  * New bugfix release
  * For more details, see:
    http://code.qt.io/cgit/qt/qtdatavis3d.git/tree/dist/changes-5.9.3/?h=v5.9.3
* Wed Nov 15 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 4
- Contains bugfixes
* Thu Nov  2 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 3
- Contains bugfixes
* Mon Oct 30 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 2
- Contains bugfixes
* Mon Oct  9 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 1
- For more information visit:
    https://blog.qt.io/blog/2017/10/09/qt-5-10-beta-released/
* Sun Oct  8 2017 lbeltrame@kde.org
- Update to 5.9.2
  * For more details please see:
    https://blog.qt.io/blog/2017/10/06/qt-5-9-2-released/
* Mon Sep 25 2017 fabian@ritter-vogt.de
- Update to 5.10 Alpha 1
- For more information visit:
    https://blog.qt.io/blog/2017/09/13/qt-5-10-alpha-released/
* Tue Jul  4 2017 fabian@ritter-vogt.de
- Update to 5.9.1
  * For more details please see:
    http://blog.qt.io/blog/2017/06/30/qt-5-9-1-released/
* Wed May 31 2017 fabian@ritter-vogt.de
- Update to 5.9.0 final
* Mon May 29 2017 fabian@ritter-vogt.de
- Drop -docs subackage, part of libqt5-qtdoc
* Wed May 24 2017 fabian@ritter-vogt.de
- Update to 5.9.0 RC:
  * For more details please see:
    http://lists.qt-project.org/pipermail/announce/2017-May/000115.html
    and https://wiki.qt.io/New_Features_in_Qt_5.9
* Wed Dec 28 2016 jengelh@inai.de
- RPM group fixup and summary improvement.
* Wed Dec 14 2016 hrvoje.senjan@gmail.com
- Update to 5.7.1
  * For more details please see:
    https://blog.qt.io/blog/2016/12/14/qt-5-7-1-released/
    and https://www.qt.io/qt5-7/
* Fri Jul 29 2016 termim@gmail.com
- initial checkin
